# Dokusu

[![GitHub license](https://img.shields.io/github/license/Chenkail/dokusu)](https://github.com/Chenkail/dokusu/blob/main/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/dokusu/badge/?version=latest)](https://dokusu.readthedocs.io/en/latest/?badge=latest)

A library for solving sudoku puzzles. Documentation available at https://dokusu.readthedocs.io/

